Skip to main contentModule id
Source - define_snowflake_id
snowflake - A macro for defining a bit layout for a custom Snowflake ID using four
required components:
reserved, timestamp, machine_id, and sequence. - define_ulid
ulid - A macro for defining a bit layout for a custom Ulid using three required
components:
reserved, timestamp, and random.
- SnowflakeDiscordId
snowflake - A 64-bit Snowflake ID using the Discord layout
- SnowflakeInstagramId
snowflake - A 64-bit Snowflake ID using the Instagram layout
- SnowflakeMastodonId
snowflake - A 64-bit Snowflake ID using the Mastodon layout
- SnowflakeTwitterId
snowflake - A 64-bit Snowflake ID using the Twitter layout
- ULID
ulid - A 128-bit ULID
- BeBytes
- A trait for types that can be encoded to and decoded from big-endian bytes.
- Id
- A trait for types that wrap a primitive scalar identifier.
- SnowflakeId
snowflake - A trait representing a layout-compatible Snowflake ID generator.
- ToU64
- Trait for converting numeric-like values into a
u64. - UlidId
ulid - Trait for layout-compatible ULID-style identifiers.