Skip to main contentModule generator
Source - thread_local
thread-local and ulid - Thread-local ULID generation utilities.
- AtomicSnowflakeGenerator
target_has_atomic=64 and atomic and snowflake - A lock-free Snowflake ID generator suitable for multi-threaded environments.
- BasicMonoUlidGenerator
basic and ulid - A monotonic ULID-style ID generator suitable for single-threaded
environments.
- BasicSnowflakeGenerator
basic and snowflake - A non-concurrent Snowflake ID generator suitable for single-threaded
environments.
- BasicUlidGenerator
basic and ulid - A non-monotonic ULID-style ID generator suitable for multi-threaded
environments.
- LockMonoUlidGenerator
lock and ulid - A lock-based monotonic ULID-style ID generator suitable for multi-threaded
environments.
- LockSnowflakeGenerator
lock and snowflake - A lock-based Snowflake ID generator suitable for multi-threaded
environments.
- Mutex
lock and non-parking-lot - A mutual exclusion primitive useful for protecting shared data
- MutexGuard
lock and non-parking-lot - An RAII implementation of a “scoped lock” of a mutex. When this structure is
dropped (falls out of scope), the lock will be unlocked.
- PoisonError
lock and non-parking-lot - A type of error which can be returned whenever a lock is acquired.
- Error
- All error variants that
ferroid can emit. - Poll
- Represents the result of attempting to generate a new ID.
- SnowflakeGenerator
snowflake - A minimal interface for generating Snowflake IDs.
- UlidGenerator
ulid - A minimal interface for generating ULIDs.
- Result
- A result type that is infallible by default.