#[non_exhaustive]pub enum Error<E> {
DecodeOverflow {
id: E,
},
Base32Error(Error<E>),
}Available on crate feature
serde only.Expand description
Errors that can occur while decoding IDs.
This error type is generic over the decoded ID type E, which allows
including the decoded ID in case of overflow. This can help callers inspect
or log invalid IDs during error handling.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
DecodeOverflow
The decoded value exceeds the valid range for the target ID type.
This occurs when the input string sets reserved or unused high bits.
Fields

id: EThe decoded ID value, which failed validation.
Base32Error(Error<E>)
Available on crate feature
base32 only.An error occurred during Crockford Base32 decoding.
This wraps the crate::base32::Error type and is only available when
the base32 feature is enabled.